MatchMakerActivation.prepare\_web\_widget()
=============================================================

.. currentmodule:: alfred3_interact.page

.. automethod:: MatchMakerActivation.prepare_web_widget
